import { CloudAuthView } from 'alinea/cloud/view/CloudAuth';
import { Preview } from 'alinea/core/Preview';
import { Auth } from './Auth.js';
import { Schema } from './Schema.js';
import { Type } from './Type.js';
import { Workspace, WorkspaceData } from './Workspace.js';
export interface DashboardConfig {
    handlerUrl: string;
    dashboardUrl: string;
    auth?: Auth.View;
    /** Compile all static assets for the dashboard to this dir */
    staticFile?: string;
}
/** Configuration options */
export interface Config {
    /** A schema describing the types of entries */
    schema: Schema;
    /** A record containing workspace configurations */
    workspaces: Record<string, Workspace>;
    /** A url which will be embedded in the dashboard for live previews */
    preview?: Preview;
    /** Every edit will pass through a draft phase before being published */
    enableDrafts?: boolean;
    /** The interval in seconds at which the frontend will poll for updates */
    syncInterval?: number;
    /**
      publicDir?: string
    dashboardFile?: string
    handlerUrl?:
    */
    dashboard?: DashboardConfig;
}
export declare namespace Config {
    function mainWorkspace(config: Config): WorkspaceData;
    function type(config: Config, name: string): Type | undefined;
    function hasAuth(config: Config): boolean;
    function validate(config: Config): void;
}
/** Create a new config instance */
export declare function createConfig<Definition extends Config>(definition: Definition): Definition & {
    schema: {
        MediaLibrary: Type<{
            title: import("alinea/field/hidden").HiddenField<string>;
            path: import("alinea/field/hidden").HiddenField<string>;
        }>;
        MediaFile: Type<{
            title: import("alinea/field/hidden").HiddenField<string>;
            path: import("alinea/field/hidden").HiddenField<string>;
            location: import("alinea/field/hidden").HiddenField<string>;
            extension: import("alinea/field/hidden").HiddenField<string>;
            size: import("alinea/field/hidden").HiddenField<number>;
            hash: import("alinea/field/hidden").HiddenField<string>;
            width: import("alinea/field/hidden").HiddenField<number>;
            height: import("alinea/field/hidden").HiddenField<number>;
            preview: import("alinea/field/hidden").HiddenField<string>;
            averageColor: import("alinea/field/hidden").HiddenField<string>;
            focus: import("alinea/field/hidden").HiddenField<{
                x: number;
                y: number;
            }>;
            thumbHash: import("alinea/field/hidden").HiddenField<string>;
        }>;
    };
    dashboard: {
        handlerUrl?: string | undefined;
        dashboardUrl?: string | undefined;
        auth: Auth.View | typeof CloudAuthView;
        staticFile?: string | undefined;
    };
};
